# Authors

- Dario d'Andrea, <mailto:dariod@playtika.com>
- Shahar Bar, <mailto:shaharbar1@gmail.com>
- Jerome Carayol, <mailto:jeromec@playtika.com>
- Stefano Piazza, <mailto:stefanop@playtika.com>
- Ron Shiff, <mailto:ron.shiff1@gmail.com>
- Raphael Steinmann, <mailto:raphaels@playtika.com>
- Yoav Tulpan, <mailto:yoavtp@gmail.com>"
- Armand Valsesia, <mailto:armandv@playtika.com>
